==> YNQ-1.5.2_Linux_S_CP.zip: YNQ-1.5.2_Linux_S_CP/NQ Library Reference/html/search/variables_64.js <==
var searchData=
[
  ['data',['data',['../structNQ__IOVecBuffer.html#aa89afe53012afdf83b5b389016ab8e6c',1,'NQ_IOVecBuffer::data()'],['../structCMIOVecBlob.html#a5b2c82d78517840ee7da9d768f622eea',1,'CMIOVecBlob::data()']]],
  ['datafile',['dataFile',['../structSYPrinterDriver.html#ab3bdcdfc20046eafbb81d054a9e6a4d0',1,'SYPrinterDriver']]],
  ['datatype',['dataType',['../structSYPrinterInfo.html#acd3f1acc09a23a27d3b0750d29c18193',1,'SYPrinterInfo']]],
  ['day',['day',['../structSYTimeFragments.html#ac28facb32c70251a66287a8f8164d0f8',1,'SYTimeFragments']]],
  ['defaultdatatype',['defaultDataType',['../structSYPrinterDriver.html#a0b98acd103a7913c75cb105e55469d05',1,'SYPrinterDriver']]],
  ['defaultpriority',['defaultPriority',['../structSYPrinterInfo.html#ab48e48710a51ba27c1c5ded84cb89fda',1,'SYPrinterInfo']]],
  ['defaultsource',['defaultSource',['../structSYDeviceMode.html#a7c8df98bfd4009898a70814ecea6eeb9',1,'SYDeviceMode']]],
  ['dependentfiles',['dependentFiles',['../structSYPrinterDriver.html#ac8b29383e668ad7ac53d0306220a544f',1,'SYPrinterDriver']]],
  ['devicenotselectedtimeout',['deviceNotSelectedTimeout',['../structSYPrinterInfo.html#acacfaa3156fc4bdb4e07ba57ee4deaef',1,'SYPrinterInfo']]],
  ['devmode',['devMode',['../structSYPrinterInfo.html#a9e24545b82b72cdb28be12c2908329e4',1,'SYPrinterInfo']]],
  ['dialect',['dialect',['../structCCServerInfo.html#a0c6ea5c14c29944549e8dd222ee6412f',1,'CCServerInfo']]],
  ['displayflags',['displayFlags',['../structSYDeviceMode.html#a8bcc366c44c95b7364e0c4017722f25d',1,'SYDeviceMode']]],
  ['displayfrequency',['displayFrequency',['../structSYDeviceMode.html#aacaace9ae9bc398cf22ba07417afba6f',1,'SYDeviceMode']]],
  ['dithertype',['ditherType',['../structSYDeviceMode.html#a68f5cd7298ac1e35c892612ade423982',1,'SYDeviceMode']]],
  ['documentname',['documentName',['../structSYPrintJobInfo.html#ad43407ab5916f56488ebcdb206f418c6',1,'SYPrintJobInfo']]],
  ['domain',['domain',['../structAMCredentialsA.html#a0513425a6c69fd1471bd16e933abfd5e',1,'AMCredentialsA::domain()'],['../structAMCredentials.html#acc2ee1f3d9a31f36e030107f15ae2e54',1,'AMCredentials::domain()']]],
  ['driverdate',['driverDate',['../structSYPrinterDriver.html#ae96e88ed32f24421c93effe7fe16892d',1,'SYPrinterDriver']]],
  ['driverextradata',['driverExtraData',['../structSYDeviceMode.html#af58c58230230ab0c08e809cd791844e1',1,'SYDeviceMode']]],
  ['driverextralength',['driverExtraLength',['../structSYDeviceMode.html#acbb67638516f22b87fc22ea0aaf7769d',1,'SYDeviceMode']]],
  ['drivername',['driverName',['../structSYPrinterInfo.html#ae310f15ef2104b3b047e7afea12bc3f7',1,'SYPrinterInfo']]],
  ['driverpath',['driverPath',['../structSYPrinterDriver.html#ae95ebc3e6117a7011ccc4670b35c3250',1,'SYPrinterDriver']]],
  ['driverversion',['driverVersion',['../structSYDeviceMode.html#aa4ec29e5cc438b14223ea7a476fe410f',1,'SYDeviceMode::driverVersion()'],['../structSYPrinterDriver.html#a446d0d7250b2652f9306a65e68532808',1,'SYPrinterDriver::driverVersion()']]],
  ['driverversions',['driverVersions',['../structSYPrinterDriver.html#aaa5c0c1f0c11e3be0fcbf7585303f6fd',1,'SYPrinterDriver']]],
  ['duplex',['duplex',['../structSYDeviceMode.html#af665d76d6acf0101190b9dec66127113',1,'SYDeviceMode']]]
];

==> YNQ-1.6.2_Linux_S_CP.zip: YNQ-1.6.2_Linux_S_CP/NQ Library Reference/html/search/variables_64.js <==
var searchData=
[
  ['data',['data',['../structNQ__IOVecBuffer.html#aa89afe53012afdf83b5b389016ab8e6c',1,'NQ_IOVecBuffer::data()'],['../structCMIOVecBlob.html#a5b2c82d78517840ee7da9d768f622eea',1,'CMIOVecBlob::data()']]],
  ['datafile',['dataFile',['../structSYPrinterDriver.html#ab3bdcdfc20046eafbb81d054a9e6a4d0',1,'SYPrinterDriver']]],
  ['datatype',['dataType',['../structSYPrinterInfo.html#acd3f1acc09a23a27d3b0750d29c18193',1,'SYPrinterInfo']]],
  ['day',['day',['../structSYTimeFragments.html#ac28facb32c70251a66287a8f8164d0f8',1,'SYTimeFragments']]],
  ['defaultdatatype',['defaultDataType',['../structSYPrinterDriver.html#a0b98acd103a7913c75cb105e55469d05',1,'SYPrinterDriver']]],
  ['defaultpriority',['defaultPriority',['../structSYPrinterInfo.html#ab48e48710a51ba27c1c5ded84cb89fda',1,'SYPrinterInfo']]],
  ['defaultsource',['defaultSource',['../structSYDeviceMode.html#a7c8df98bfd4009898a70814ecea6eeb9',1,'SYDeviceMode']]],
  ['dependentfiles',['dependentFiles',['../structSYPrinterDriver.html#ac8b29383e668ad7ac53d0306220a544f',1,'SYPrinterDriver']]],
  ['devicenotselectedtimeout',['deviceNotSelectedTimeout',['../structSYPrinterInfo.html#acacfaa3156fc4bdb4e07ba57ee4deaef',1,'SYPrinterInfo']]],
  ['devmode',['devMode',['../structSYPrinterInfo.html#a9e24545b82b72cdb28be12c2908329e4',1,'SYPrinterInfo']]],
  ['dialect',['dialect',['../structCCServerInfo.html#a0c6ea5c14c29944549e8dd222ee6412f',1,'CCServerInfo']]],
  ['displayflags',['displayFlags',['../structSYDeviceMode.html#a8bcc366c44c95b7364e0c4017722f25d',1,'SYDeviceMode']]],
  ['displayfrequency',['displayFrequency',['../structSYDeviceMode.html#aacaace9ae9bc398cf22ba07417afba6f',1,'SYDeviceMode']]],
  ['dithertype',['ditherType',['../structSYDeviceMode.html#a68f5cd7298ac1e35c892612ade423982',1,'SYDeviceMode']]],
  ['divider',['divider',['../structCMLinkedListArray.html#a46b4c2788d6dbb93c0b6c6940c4461c5',1,'CMLinkedListArray']]],
  ['documentname',['documentName',['../structSYPrintJobInfo.html#ad43407ab5916f56488ebcdb206f418c6',1,'SYPrintJobInfo']]],
  ['domain',['domain',['../structAMCredentialsA.html#a0513425a6c69fd1471bd16e933abfd5e',1,'AMCredentialsA::domain()'],['../structAMCredentials.html#acc2ee1f3d9a31f36e030107f15ae2e54',1,'AMCredentials::domain()']]],
  ['driverdate',['driverDate',['../structSYPrinterDriver.html#ae96e88ed32f24421c93effe7fe16892d',1,'SYPrinterDriver']]],
  ['driverextradata',['driverExtraData',['../structSYDeviceMode.html#af58c58230230ab0c08e809cd791844e1',1,'SYDeviceMode']]],
  ['driverextralength',['driverExtraLength',['../structSYDeviceMode.html#acbb67638516f22b87fc22ea0aaf7769d',1,'SYDeviceMode']]],
  ['drivername',['driverName',['../structSYPrinterInfo.html#ae310f15ef2104b3b047e7afea12bc3f7',1,'SYPrinterInfo']]],
  ['driverpath',['driverPath',['../structSYPrinterDriver.html#ae95ebc3e6117a7011ccc4670b35c3250',1,'SYPrinterDriver']]],
  ['driverversion',['driverVersion',['../structSYDeviceMode.html#aa4ec29e5cc438b14223ea7a476fe410f',1,'SYDeviceMode::driverVersion()'],['../structSYPrinterDriver.html#a446d0d7250b2652f9306a65e68532808',1,'SYPrinterDriver::driverVersion()']]],
  ['driverversions',['driverVersions',['../structSYPrinterDriver.html#aaa5c0c1f0c11e3be0fcbf7585303f6fd',1,'SYPrinterDriver']]],
  ['duplex',['duplex',['../structSYDeviceMode.html#af665d76d6acf0101190b9dec66127113',1,'SYDeviceMode']]]
];
